@@ -33,7 +33,7 @@ public:
        
     enum RequestType {
 	/* any node services */
-	RETRIEVETABLESET, 
+	GET_TABLESETLIST,
 	LOCKINFO,
 	LOCKSTAT,
 	PARAMETERINFO,
@@ -46,9 +46,6 @@ public:
 	QUERYHISTLAST,
 	QUERYHISTCOST,
 	ADMTHREADINFO,
-	LOGTHREADINFO,
-	DBSESSIONINFO,
-	COPYINFO,
 	SHOWQUERYCACHE,
 	LISTQUERYCACHE,
 	CLEANQUERYCACHE,
@@ -65,9 +62,6 @@ public:
 	START_TABLESET,
 	STOP_TABLESET,	
 	SYNC_TABLESET,
-	GET_DBSPEC,
-	COPY_TABLESET,
-	COPY_FILE,
 	INIT_LOGS,
 	START_RECOVERY,
 	STOP_RECOVERY,
@@ -85,19 +79,13 @@ public:
 	SET_TSLOGSIZE,
 	SET_TSSORTAREASIZE,
 	SET_TSLOGUSER,
-	GET_NODELIST,
 	GET_TSINFO,
 	GET_DETAILED_TSINFO,
 	GET_ARCHLOG_INFO,
 	GET_OBJECT_INFO,
 	GET_TRANSACTION_INFO,
 	GET_BUSTAT,
-	GET_DBINFO,
-	PROP_TSINFO,
-	SET_TABLESETNODE,
 	SET_LSN,
-	SET_RUNSTATE,
-	SET_SYNCSTATE,
 	EXPORT_TABLESET,
 	IMPORT_TABLESET,
 	EXPORT_TABLE,
@@ -116,7 +104,6 @@ public:
 	SET_PERM,
 	REMOVE_PERM,
 	USER_TRACE,
-	REGISTER_HOST,
 	ADD_ARCHLOG,
 	REMOVE_ARCHLOG,
 	BEGIN_BACKUP,
@@ -125,7 +112,6 @@ public:
 	LIST_BACKUP,
 	RESTORE,
 	RECOVER,
-	SECSWITCH,
 	VERIFY_TABLESET,
 	CORRECT_TABLESET,
 	DUMP_OBJECT,
@@ -135,49 +121,14 @@ public:
 	DISABLE_QUERYCACHE,
 	SET_NUMQUERYLAST,
 	SET_NUMQUERYCOST,
-	
-	/* mediator requests */
-	MED_NOTIFY,
-	MED_DEFINE_TABLESET,
-	MED_REMOVE_TABLESET,
-	MED_RESET_TABLESET,
-	MED_CREATE_TABLESET,
-	MED_DROP_TABLESET,
-	MED_COPY_TABLESET,
-	MED_SWITCH_TABLESET,
-	MED_STOP_TABLESET,
-	MED_START_TABLESET,
-	MED_ADD_DATAFILE,
-	MED_ADD_ARCHLOG,
-	MED_REMOVE_ARCHLOG,
-	MED_GET_TABLESETLIST,
-	MED_GET_DETAILEDTABLESETINFO,
-	MED_GET_ARCHLOGINFO,
-	MED_GET_OBJECTINFO,
-	MED_GET_TRANSACTIONINFO,
-	MED_GET_BUSTAT,
-	MED_RESET_BUSTAT,
-	MED_BEGIN_BACKUP,
-	MED_EXECUTE_BACKUP,
-	MED_END_BACKUP,
-	MED_LIST_BACKUP,
-	MED_RESTORE,
-	MED_RECOVER,
-	MED_SECSWITCH,
-	MED_SECRELOCATE,
-	MED_CHECK_TABLESET,
-	MED_VERIFY_TABLESET,
-	MED_CORRECT_TABLESET,
-	MED_ENABLE_ARCHLOG,	
-	MED_DISABLE_ARCHLOG,
-	MED_ENABLE_AUTOCORRECT,	
-	MED_DISABLE_AUTOCORRECT,
-	MED_ENABLE_APPENDMODE,	
-	MED_DISABLE_APPENDMODE,
-
-	/* secondary requests */
-	SEC_MEDSWITCH,
-	SEC_MEDRELOCATE,
+	ENABLE_ARCHLOG,	
+	DISABLE_ARCHLOG,
+	ENABLE_AUTOCORRECT,	
+	DISABLE_AUTOCORRECT,
+	ENABLE_APPENDMODE,	
+	DISABLE_APPENDMODE,
+	RESET_BUSTAT,
+		
 	/* any requests */
 	SESSION_CLOSE,
 	REQTIMEOUT,
@@ -198,8 +149,6 @@ public:
 
     void setNetHandle(NetHandler *pN);
     NetHandler* getNetHandle();
-
-    ResultType reqRetrieveTableSet(const Chain& masterHost);
     
     ResultType reqLockInfo(const Chain& lockCat);
     ResultType reqLockStat();
@@ -218,9 +167,7 @@ public:
     ResultType reqNumQueryCost(unsigned numCost);
     
     ResultType reqAdmThreadInfo();
-    ResultType reqLogThreadInfo();
     ResultType reqDbSessionInfo();
-    ResultType reqCopyInfo();
 
     ResultType reqShowQueryCache(const Chain& tableSet);
     ResultType reqListQueryCache(const Chain& tableSet);
@@ -235,35 +182,30 @@ public:
 				     unsigned maxSize, unsigned hashRange);
         
     ResultType reqDbThreadAbort(unsigned threadId);
-    
+
     ResultType reqDefineTableSet(const Chain& tableSet, 
 				 const Chain& tsRoot,
-				 const Chain& primary,
-				 const Chain& secondary, 
-				 const Chain& mediator,
-				 unsigned sysFileId, unsigned tempFileId, unsigned sysFileSize, unsigned tempFileSize, unsigned appFileSize,
-				 unsigned logFileSize, unsigned logFileNum, unsigned long long sortAreaSize);
+				 unsigned sysFileSize, unsigned tmpFileSize, unsigned appFileSize,
+				 unsigned logFileSize, unsigned logFileNum,
+				 unsigned long long sortAreaSize,
+				 unsigned branchId);
+
     ResultType reqRemoveTableSet(const Chain& tableSet);
-    ResultType reqResetTableSet(const Chain& tableSet);
+
     ResultType reqCreateTableSet(const Chain& tableSet);
     ResultType reqDropTableSet(const Chain& tableSet);
-    ResultType reqStartTableSet(const Chain& tableSet, bool cleanIt, bool forceload);
+    ResultType reqStartTableSet(const Chain& tableSet, bool cleanIt, bool forceload, bool cpDump, bool noInit);
+                                
     ResultType reqStopTableSet(const Chain& tableSet);
 
-    ResultType reqVerifyTableSet(const Chain& tableSet);
-
     ResultType reqInitLogs(const Chain& tableSet);
 
     ResultType reqSyncTableSet(const Chain& tableSet, const Chain& msg, const Chain& escCmd, unsigned timeout);
 
-    ResultType reqGetDbSpec(Chain& dbSpec);
-    ResultType reqCopyTableSet(const Chain& tableSet, const Chain& secondary, const Chain& mediator);
     ResultType reqStartRecovery(const Chain& tableSet);
     ResultType reqStopRecovery(const Chain& tableSet);
-
-    ResultType reqCopyFile(const Chain& fileName, unsigned copyId = 0);
-
-    ResultType reqGetNodeList();
+       
+    ResultType reqGetTableSetList(bool getUsage = false);
     ResultType reqGetDbInfo();
     ResultType reqGetTSInfo(const Chain& tableSet);
     ResultType reqGetDetailedTSInfo(const Chain& tableSet);
@@ -273,8 +215,6 @@ public:
     ResultType reqGetObjectInfo(const Chain& tableSet);
 
     ResultType reqGetTransactionInfo(const Chain& tableSet);
-    ResultType reqPropTSInfo(Element *pTSInfo);
-    ResultType reqSetTableSetNode(const Chain& tableSet, const Chain& primary, const Chain& secondary, const Chain& mediator);
     ResultType reqSetLSN(const Chain& tableSet, unsigned long long lsn);
 
     ResultType reqSetRunState(const Chain& tableSet, const Chain& runState);
@@ -288,7 +228,9 @@ public:
     ResultType reqExportTable(const Chain& tableSet, const Chain& tableName, const Chain& exportFile, const Chain& expMode);
     ResultType reqImportTable(const Chain& tableSet, const Chain& tableName, const Chain& importFile, const Chain& impMode);
 
-    ResultType reqAddDataFile(const Chain& tableSet, const Chain& fileType, unsigned fileId, const Chain& dataFile, unsigned fileSize);
+    ResultType reqAddDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, unsigned fileSize);
+    
+    // ResultType reqAddDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, unsigned fileSize);
     
     ResultType reqShowUser();
     ResultType reqAddUser(const Chain& user, const Chain& password);
@@ -311,13 +253,13 @@ public:
     ResultType reqAddArchLog(const Chain& tableSet, const Chain& archId, const Chain& archPath);
     ResultType reqRemoveArchLog(const Chain& tableSet, const Chain& archId);
 
-    ResultType reqBeginBackup(const Chain& tableSet);
-    ResultType reqExecuteBackup(const Chain& tableSet);
-    ResultType reqEndBackup(const Chain& tableSet, bool keepTicket);
+    ResultType reqBeginBackup(const Chain& tableSet, const Chain& msg);
+    ResultType reqExecuteBackup(const Chain& tableSet, const Chain& msg);
+    ResultType reqEndBackup(const Chain& tableSet, const Chain& msg, bool keepTicket);
     ResultType reqListBackup(const Chain& tableSet, const Chain& pit);
     ResultType reqRestore(const Chain& tableSet, const Chain& backupId);
     ResultType reqRecover(const Chain& tableSet, const Chain& pit, unsigned long long targetlsn);
-    ResultType reqSecSwitch(const Chain& tableSet, const Chain& secondary);
+
 
     ResultType reqDumpObject(const Chain& tableSet, CegoObject::ObjectType type, const Chain& objName);
 
@@ -344,70 +286,26 @@ public:
     
     ResultType reqEnableQueryCache(const Chain& tableSet);
     ResultType reqDisableQueryCache(const Chain& tableSet);
+
+
+    ResultType reqCheckTableSet(const Chain& tableSet);
+    ResultType reqVerifyTableSet(const Chain& tableSet);
+    ResultType reqCorrectTableSet(const Chain& tableSet);
+
+    ResultType reqEnableArchLog(const Chain& tableSet);
+    ResultType reqDisableArchLog(const Chain& tableSet);
+
+    ResultType reqEnableAppendMode(const Chain& tableSet);
+    ResultType reqDisableAppendMode(const Chain& tableSet);
+
+    ResultType reqEnableAutoCorrect(const Chain& tableSet);
+    ResultType reqDisableAutoCorrect(const Chain& tableSet);
+
+
+    ResultType reqResetBUStat(const Chain& tableSet);
     
     ResultType sendReq(const Chain& reqType, Element* pRoot);
-
-    // mediator services 
-    ResultType medNotifyMediator(const Chain& hostName, const Chain& status, 
-				 const ListT<Chain>& tsList, const ListT<Chain>& runList, const ListT<Chain>& syncList);
-
-    ResultType medStartTableSet(const Chain& tableSet, bool cleanIt, bool forceload, bool cpDump, bool noInit);
-    ResultType medStopTableSet(const Chain& tableSet);
-
-    ResultType medDefineTableSet(const Chain& tableSet, 
-				 const Chain& tsRoot,
-				 const Chain& primary,
-				 const Chain& secondary,
-				 unsigned sysFileSize, unsigned tmpFileSize, unsigned appFileSize,
-				 unsigned logFileSize, unsigned logFileNum,
-				 unsigned long long sortAreaSize,
-				 unsigned branchId);
     
-    ResultType medDropTableSet(const Chain& tableSet);
-    ResultType medRemoveTableSet(const Chain& tableSet);
-    ResultType medResetTableSet(const Chain& tableSet);
-    ResultType medCreateTableSet(const Chain& tableSet);
-    ResultType medCopyTableSet(const Chain& tableSet);
-    ResultType medSwitchTableSet(const Chain& tableSet);
-
-    ResultType medAddDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, unsigned fileSize);
-    ResultType medAddArchLog(const Chain& tableSet, const Chain& archId, const Chain& archPath);
-    ResultType medRemoveArchLog(const Chain& tableSet, const Chain& archId);
-    ResultType medGetTableSetList(bool getUsage = false);
-    ResultType medGetDetailedTableSetInfo(const Chain& tableSet);
-    ResultType medGetObjectInfo(const Chain& tableSet);
-    ResultType medGetArchLogInfo(const Chain& tableSet);
-    ResultType medGetTransactionInfo(const Chain& tableSet);
-    ResultType medGetBUStatInfo(const Chain& tableSet);
-    ResultType medResetBUStat(const Chain& tableSet);
-
-    ResultType medBeginBackup(const Chain& tableSet, const Chain& msg);
-    ResultType medExecuteBackup(const Chain& tableSet, const Chain& msg);
-    ResultType medEndBackup(const Chain& tableSet, const Chain& msg, bool keepTicket);
-    ResultType medListBackup(const Chain& tableSet, const Chain& pit);
-    ResultType medRestore(const Chain& tableSet, const Chain& backupId);   
-    ResultType medRecover(const Chain& tableSet, const Chain& pit, unsigned long long lsn);
-
-    ResultType medSecSwitch(const Chain& tableSet);
-
-    ResultType medSecRelocate(const Chain& tableSet, const Chain& hostName);
-
-    ResultType medCheckTableSet(const Chain& tableSet);
-    ResultType medVerifyTableSet(const Chain& tableSet);
-    ResultType medCorrectTableSet(const Chain& tableSet);
-
-    ResultType medEnableArchLog(const Chain& tableSet);
-    ResultType medDisableArchLog(const Chain& tableSet);
-
-    ResultType medEnableAppendMode(const Chain& tableSet);
-    ResultType medDisableAppendMode(const Chain& tableSet);
-
-    ResultType medEnableAutoCorrect(const Chain& tableSet);
-    ResultType medDisableAutoCorrect(const Chain& tableSet);
-
-    ResultType secMedSwitch(const Chain& tableSet);
-    ResultType secMedRelocate(const Chain& tableSet, const Chain& hostName);
-
     RequestType acceptRequest();
 
     void sendInfo(const Chain& info);
@@ -440,7 +338,6 @@ public:
     void getDbThreadHistory(CegoTableObject& oe, ListT<ListT< CegoFieldValue > > & info, Chain& format);
 
     void getAdmThreadInfo(CegoTableObject& oe, ListT<ListT< CegoFieldValue > > & info, Chain& format);
-    void getLogThreadInfo(CegoTableObject& oe, ListT<ListT< CegoFieldValue > > & info, Chain& format);
     void getDbSessionInfo(CegoTableObject& oe, ListT<ListT< CegoFieldValue > > & info);
     void getCopyInfo(CegoTableObject& oe, ListT<ListT< CegoFieldValue > > & info, Chain& format);
     bool getCacheInfo(CegoTableObject& oe, ListT<ListT< CegoFieldValue > > & info, Chain& format);
@@ -448,9 +345,6 @@ public:
 
     Element* getTableSetInfo();
 
-    void getTableSetCheck(CegoTableObject& oe, ListT<ListT< CegoFieldValue > > & info);
-    Element* getTableSetCheckInfo();
-
     Element* getTSInfo();
     Element* getArchInfo();
     Element* getObjectInfo();
@@ -515,9 +409,6 @@ public:
     void getBackupManager(Chain& progName);
     
     void getLockCat(Chain& lockCat);
-    void getPrimary(Chain& primary);
-    void getSecondary(Chain& secondary);
-    void getMediator(Chain& mediator);
     void getSysFileId(unsigned& sysFid);
     void getTmpFileId(unsigned& tmpFid);
     void getSysSize(unsigned& sysSize);
@@ -537,10 +428,8 @@ public:
     void getDataId(Chain& dataId);
     void getLSN(unsigned long long& lsn);
     void getRunState(Chain& runState);
-    void getSyncState(Chain& syncState);
     void getPit(Chain& pit);
     void getIsStructure(bool& isStructure);
-    void getTableSyncStateList(ListT<Chain>& tsList, ListT<Chain>& runList, ListT<Chain>& syncList);
     void getKeepTicket(bool& keepTicket);
     void getMode(Chain& mode);
     bool getCleanup();
