@@ -35,7 +35,7 @@ CegoAggregation::CegoAggregation(bool isDistinct)
     _isDistinct = isDistinct;
 }
 
-CegoAggregation::CegoAggregation(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+CegoAggregation::CegoAggregation(char* buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pExpr = 0;
     decode(buf, pGTM, pBlock, tabSetId);
@@ -163,7 +163,7 @@ void CegoAggregation::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoAggregation::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
+void CegoAggregation::decode(char *buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {   
     if ( _pExpr )
     {
