@@ -38,7 +38,7 @@ public:
     enum AggType { MIN, MAX, AVG, SUM, COUNT };
     
     CegoAggregation(bool isDistinct);
-    CegoAggregation(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    CegoAggregation(char* buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoAggregation(AggType type, CegoExpr* pExpr, bool isDistinct = false);
     ~CegoAggregation();
 
@@ -66,7 +66,7 @@ public:
     ListT<CegoAttrDesc*> getAttrRefList() const;
 
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    void decode(char *buf, CegoQueryManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     unsigned getEncodingLength(CegoProcBlock *pBlock) const;
     
     Chain getId(CegoProcBlock *pBlock) const;
