@@ -35,8 +35,8 @@ public:
 
     CegoBTreeObject();
     CegoBTreeObject(const CegoBTreeObject& oe);
-    CegoBTreeObject(int tabSetId, ObjectType type, const Chain& objName);
-    CegoBTreeObject(int tabSetId, ObjectType type, const Chain& objName, const ListT<CegoField>& schema, const Chain& tabName);
+    CegoBTreeObject(unsigned tabSetId, ObjectType type, const Chain& objName);
+    CegoBTreeObject(unsigned tabSetId, ObjectType type, const Chain& objName, const ListT<CegoField>& schema, const Chain& tabName);
     
     ~CegoBTreeObject();
     
@@ -45,9 +45,9 @@ public:
     
     void increaseRelevance();
     void decreaseRelevance();
-    int getRelevance() const;
+    unsigned getRelevance() const;
     
-    int getEntrySize() const;
+    unsigned getEntrySize() const;
 
     void encode(char *buf) const;
     void decode(char *buf);
@@ -60,7 +60,7 @@ public:
     bool operator == ( const CegoBTreeObject& oe);
 
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId) const;
+    Chain toChain(unsigned defTabSetId) const;
     CegoContentObject* clone(bool isAttrRef = false);
     
     Chain getInfo() const;
@@ -68,6 +68,6 @@ public:
 private:
 
     PageIdType _pageId;
-    int _relevance; 
+    unsigned _relevance; 
 };
 #endif
