@@ -151,175 +151,6 @@ bool CegoDatabaseManager::ObjectRecord::operator == ( const CegoDatabaseManager:
     return false;
 }
 
-//////////////////
-// CopyRecord //
-//////////////////
-
-CegoDatabaseManager::CopyRecord::CopyRecord()
-{
-}
-
-CegoDatabaseManager::CopyRecord::CopyRecord(const Chain& tableSet, const Chain& targetHost, const Chain& mediatorHost, const Chain& user, const Chain& passwd, const Chain& msg)
-{
-    _id = 0;
-    _tableSet = tableSet;
-    _targetHost = targetHost;
-    _mediatorHost = mediatorHost;
-    _user = user;
-    _passwd = passwd;
-    _msg = msg;
-}
-
-CegoDatabaseManager::CopyRecord::~CopyRecord()
-{
-}
-
-const Chain& CegoDatabaseManager::CopyRecord::getTableSet() const
-{
-    return _tableSet;
-}
-
-const Chain& CegoDatabaseManager::CopyRecord::getTargetHost() const
-{
-    return _targetHost;
-}
-
-const Chain& CegoDatabaseManager::CopyRecord::getMediatorHost() const
-{
-    return _mediatorHost;
-}
-
-const Chain& CegoDatabaseManager::CopyRecord::getUser() const
-{
-    return _user;
-}
-
-const Chain& CegoDatabaseManager::CopyRecord::getPasswd() const
-{
-    return _passwd;
-}
-
-void CegoDatabaseManager::CopyRecord::setMsg(const Chain& msg)
-{
-    _msg = msg;
-}
-
-const Chain& CegoDatabaseManager::CopyRecord::getMsg() const
-{
-    return _msg;
-}
-
-unsigned CegoDatabaseManager::CopyRecord::getId() const
-{
-    return _id;
-}
-
-void CegoDatabaseManager::CopyRecord::setId(unsigned id)
-{
-    _id = id;
-}
-
-CegoDatabaseManager::CopyRecord& CegoDatabaseManager::CopyRecord::operator = ( const CegoDatabaseManager::CopyRecord& cr)
-{
-    _id = cr._id;
-    _tableSet = cr._tableSet;
-    _targetHost = cr._targetHost;
-    _mediatorHost = cr._mediatorHost;
-    _user = cr._user;
-    _passwd = cr._passwd;
-    _msg = cr._msg;
-    return (*this);   
-}
-
-bool CegoDatabaseManager::CopyRecord::operator == ( const CegoDatabaseManager::CopyRecord& cr)
-{
-    if ( _tableSet == cr._tableSet && _targetHost == cr._targetHost)
-	return true;
-    return false;
-}
-
-/////////////////////
-// DbSessionRecord //
-/////////////////////
-
-CegoDatabaseManager::DbSessionRecord::DbSessionRecord()
-{
-}
-
-CegoDatabaseManager::DbSessionRecord::DbSessionRecord(CegoDistDbHandler* pHandler)
-{
-    _pHandler = pHandler;
-}
-
-CegoDatabaseManager::DbSessionRecord::DbSessionRecord(const Chain& hostName, const Chain& tableSet, 
-				     const Chain& userName, CegoDistDbHandler* pHandler)
-{
-    _hostName = hostName;
-    _tableSet = tableSet;
-    _userName = userName;
-    _pHandler = pHandler;
-    _lastUsed = Datetime().asLong();
-}
-
-CegoDatabaseManager::DbSessionRecord::~DbSessionRecord()
-{
-}
-
-const Chain& CegoDatabaseManager::DbSessionRecord::getHostName() const
-{
-    return _hostName;
-}
-
-const Chain& CegoDatabaseManager::DbSessionRecord::getTableSet() const
-{
-    return _tableSet;
-}
-
-const Chain& CegoDatabaseManager::DbSessionRecord::getUserName() const
-{
-    return _userName;
-}
-
-CegoDistDbHandler* CegoDatabaseManager::DbSessionRecord::getDbHandler() const
-{
-    return _pHandler;
-}
-
-bool CegoDatabaseManager::DbSessionRecord::isUsed() const
-{
-    return _isUsed;
-}
-void CegoDatabaseManager::DbSessionRecord::setUsed(bool isUsed)
-{
-    _isUsed = isUsed;
-}
-
-long long CegoDatabaseManager::DbSessionRecord::getTSLastUsed()
-{
-    return _lastUsed;
-}
-
-void CegoDatabaseManager::DbSessionRecord::setTSLastUsed(long long ts)
-{
-    _lastUsed = ts;
-}
-
-CegoDatabaseManager::DbSessionRecord& CegoDatabaseManager::DbSessionRecord::operator = ( const CegoDatabaseManager::DbSessionRecord& sr)
-{
-    _hostName = sr._hostName;
-    _tableSet = sr._tableSet;
-    _userName = sr._userName;
-    _pHandler = sr._pHandler;
-    _lastUsed = sr._lastUsed;    
-    return (*this);
-}
-
-bool CegoDatabaseManager::DbSessionRecord::operator == ( const CegoDatabaseManager::DbSessionRecord& sr)
-{
-    if ( _pHandler == sr._pHandler )
-	return true;
-    return false;
-}
 
 /////////////////////////
 // CegoDatabaseManager //
@@ -380,7 +211,6 @@ CegoDatabaseManager::CegoDatabaseManager(const Chain& xmlDef, const Chain& lckFi
 	_pQueryCache[i] = 0;
 	_pTableCache[i]= 0;
     }
-    _nextCopyId=1;
 
     _logConfigured=false;
 
@@ -577,13 +407,6 @@ void CegoDatabaseManager::startRecovery(const Chain& tableSet)
     V();
 }
 
-void CegoDatabaseManager::startCopy(const Chain& tableSet, const Chain& targetHost, const Chain& mediatorHost, const Chain& user, const Chain& passwd, const Chain& msg)
-{
-    PW();
-    _copyList.Insert( CopyRecord( tableSet, targetHost, mediatorHost, user, passwd, msg));
-    V();
-}
-
 bool CegoDatabaseManager::nextRecovery(Chain& tableSet)
 {
     PW();
@@ -599,76 +422,6 @@ bool CegoDatabaseManager::nextRecovery(Chain& tableSet)
     return false;
 }
 
-bool CegoDatabaseManager::nextCopy(unsigned& id, Chain& tableSet, Chain& targetHost, Chain& mediatorHost, Chain& user, Chain& passwd)
-{
-    PW();
-    CopyRecord *pCR = _copyList.First();
-    while ( pCR )
-    {
-	if ( pCR->getId() == 0 )
-	{
-	    id = _nextCopyId++;
-	    pCR->setId(id);
-
-	    tableSet = pCR->getTableSet();
-	    targetHost = pCR->getTargetHost();
-	    mediatorHost = pCR->getMediatorHost();
-	    user = pCR->getUser();
-	    passwd = pCR->getPasswd();
-	    
-	    // _copyList.Remove(*pCR);
-	    V();
-	    return true;
-	}
-	pCR = _copyList.Next();
-    }
-    V();
-    return false;
-}
-
-void CegoDatabaseManager::setCopyStatus(unsigned id, const Chain& msg)
-{
-    PW();
-    CopyRecord *pCR = _copyList.First();
-    while ( pCR )
-    {
-	if ( pCR->getId() == id )
-	{
-	    pCR->setMsg(msg);
-
-	    V();
-	    return;
-	}
-	pCR = _copyList.Next();
-    }
-    V();
-    return;
-}
-
-Element* CegoDatabaseManager::getCopyInfo()
-{
-    Element* pCopyInfo = new Element(XML_COPYINFO_ELEMENT);
-    
-    PR();
-    CopyRecord *pCR = _copyList.First();
-    while ( pCR )
-    {	
-	Element *pN = new Element(XML_COPY_ELEMENT);
-
-	pN->setAttribute(XML_CID_ATTR, pCR->getId());
-	pN->setAttribute(XML_HOSTNAME_ATTR, pCR->getTargetHost());
-	pN->setAttribute(XML_TABLESET_ATTR, pCR->getTableSet());
-	pN->setAttribute(XML_STATUS_ATTR, pCR->getMsg());
-	
-	pCopyInfo->addContent(pN);
-
-	pCR = _copyList.Next();
-    }
-
-    V();
-
-    return pCopyInfo;
-}
 
 void CegoDatabaseManager::useObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, ObjectUseMode mode, CegoTableManager *pTabMng)
 {
@@ -934,25 +687,21 @@ void CegoDatabaseManager::printObjectList()
     V();
 }
 
-void CegoDatabaseManager::setThreadInfo(unsigned numDbThread, unsigned numAdmThread, unsigned numLogThread)
+void CegoDatabaseManager::setThreadInfo(unsigned numDbThread, unsigned numAdmThread)
 {
     _numDbThread = numDbThread;
     _numAdmThread = numAdmThread;
-    _numLogThread = numLogThread;
     _activeDbThread = 0;
     _activeAdmThread = 0;
-    _activeLogThread = 0;
 }
     
-void CegoDatabaseManager::getThreadInfo(unsigned& numDbThread, unsigned& numAdmThread, unsigned& numLogThread,
+void CegoDatabaseManager::getThreadInfo(unsigned& numDbThread, unsigned& numAdmThread,
 		   unsigned& activeDbThread, unsigned& activeAdmThread, unsigned& activeLogThread)
 {
     numDbThread = _numDbThread;
     numAdmThread = _numAdmThread;
-    numLogThread = _numLogThread;
     activeDbThread = _activeDbThread;
     activeAdmThread = _activeAdmThread;
-    activeLogThread = _activeLogThread;
 }
 
 void CegoDatabaseManager::increaseActiveAdmThread()
@@ -975,16 +724,6 @@ void CegoDatabaseManager::decreaseActiveDbThread()
     _activeDbThread--;
 }
 
-void CegoDatabaseManager::increaseActiveLogThread()
-{
-    _activeLogThread++;
-}
-
-void CegoDatabaseManager::decreaseActiveLogThread()
-{
-    _activeLogThread--;
-}
-
 void CegoDatabaseManager::getDBMLockStat(Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockName = dbmLock.getId();
@@ -1000,180 +739,6 @@ void CegoDatabaseManager::getDBMLockStat(Chain& lockName, unsigned& lockCount, u
 	sumWrDelay = dbmLock.sumWriteDelay() / LCKMNG_DELRES;
 }
 
-CegoDistDbHandler* CegoDatabaseManager::allocateSession(const Chain& hostName, const Chain& tableSet,
-							const Chain& userName, const Chain& password)
-{
-    PW();    
-
-    CegoDistDbHandler* pSession = 0;
-    
-    try
-    {
-	DbSessionRecord *pSR = _dbSessionList.First();
-	while ( pSR )
-	{
-	    if ( pSR->getHostName() == hostName 
-		 && pSR->getTableSet() == tableSet 
-		 && pSR->getUserName() == userName 
-		 && pSR->isUsed() == false )
-	    {
-		pSR->setUsed(true);
-		Datetime dt;
-		pSR->setTSLastUsed( dt.asLong() );
-		
-		V();
-		
-		return pSR->getDbHandler();
-	    }
-	    pSR = _dbSessionList.Next();
-	}
-	
-	// create new session
-	pSession = createSession(hostName, tableSet, userName, password);
-	_dbSessionList.Insert( DbSessionRecord(hostName, tableSet, userName, pSession));
-    }
-    catch ( Exception e )
-    {
-	V();
-	throw Exception(EXLOC, "Cannot allocate db session", e);
-    }
-
-    V();
-    return pSession;
-}
-
-void CegoDatabaseManager::releaseSession(CegoDistDbHandler* pHandler)
-{
-    PW();
-    
-    DbSessionRecord *pSR = _dbSessionList.First();
-    while ( pSR )
-    {
-	if ( pSR->getDbHandler() == pHandler  )
-	{
-	    pSR->setUsed(false);
-	    
-	    V();
-	    
-	    return;
-	}
-	pSR = _dbSessionList.Next();
-    }
-    
-    V();
-    
-    Chain msg = Chain("Cannot release session for unknown db handle"); 
-    throw Exception(EXLOC, msg);
-}
-
-void CegoDatabaseManager::cleanSession(unsigned lifetime)
-{
-    PW();
-    
-    Datetime dt;
-    
-    DbSessionRecord *pSR = _dbSessionList.First();
-    while ( pSR )
-    {
-	if ( pSR->getTSLastUsed() <  ( dt.asLong() - lifetime )  )
-	{
-	    if ( pSR->isUsed() == false )
-	    {
-		closeSession(pSR->getDbHandler());
-		_dbSessionList.Remove( DbSessionRecord(pSR->getDbHandler()));
-		pSR = _dbSessionList.First();
-	    }
-	}
-	pSR = _dbSessionList.Next();
-    }
-    
-    V();   
-}
-
-Element* CegoDatabaseManager::getSessionInfo(unsigned lifetime)
-{
-    Element* pSessionInfo = new Element(XML_DBSESSIONINFO_ELEMENT);
-    
-    DbSessionRecord *pSR = _dbSessionList.First();
-    while ( pSR )
-    {	
-	Element *pN = new Element(XML_DBSESSION_ELEMENT);
-	pN->setAttribute(XML_HOSTNAME_ATTR, pSR->getHostName());
-	pN->setAttribute(XML_TABLESET_ATTR, pSR->getTableSet());
-	pN->setAttribute(XML_USER_ATTR, pSR->getUserName());
-	if ( pSR->isUsed() )
-	    pN->setAttribute(XML_ISUSED_ATTR, XML_TRUE_VALUE);
-	else
-	    pN->setAttribute(XML_ISUSED_ATTR, XML_FALSE_VALUE);
-
-	Datetime dt;
-	pN->setAttribute(XML_TTL_ATTR, Chain(pSR->getTSLastUsed() + (long long)lifetime - dt.asLong()));	
-
-	pSessionInfo->addContent(pN);
-
-	pSR = _dbSessionList.Next();
-    }
-    return pSessionInfo;
-}
-
-CegoDistDbHandler* CegoDatabaseManager::createSession(const Chain& hostName, const Chain& tableSet,
-						  const Chain& userName, const Chain& password)
-{
-    unsigned portNo;
-    getDataPort(portNo);
-    
-    Net n( NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN, getMaxSendLen() );
-    NetHandler* pN = 0;
-    CegoDistDbHandler *pSH = 0;
-
-    try     
-    {
-
-#ifdef DEBUG
-	log(_modId, Logger::DEBUG, Chain("Connecting to ") + Chain(hostName) + Chain(" on port ") + Chain(portNo));
-#endif
-
-	pN = n.connect(hostName, portNo);
-	pSH = new CegoDistDbHandler(pN, _protType, this);
-	
-#ifdef DEBUG
-	log(_modId, Logger::DEBUG, Chain("Using user ") + userName + Chain("/") + password); 
-#endif
-	pSH->requestSession(tableSet, userName, password, false);
-    }
-    catch ( Exception e ) 
-    {
-	if ( pSH )
-	{
-	    delete pSH;
-	}
-	
-	if ( pN )
-	{
-	    delete pN;
-	}
-	
-	Chain msg = Chain("Cannot create session to ") + hostName;
-	throw Exception(EXLOC, msg);
-    }
-
-    return pSH;
-}
-
-void CegoDatabaseManager::closeSession(CegoDistDbHandler* pSH)
-{
-#ifdef DEBUG
-    log(_modId, Logger::DEBUG, Chain("Closing session ..."));     
-#endif
-
-    pSH->closeSession();
-
-    NetHandler *pN = pSH->getNetHandler();
-
-    delete pSH;
-    delete pN;
-}
-
 void CegoDatabaseManager::configureLogger(Logger::LogLevel level)
 {
     for ( unsigned i=1; i< getMapSize() ; i++)
