@@ -26,11 +26,13 @@
 
 // CEGO INCLUDES
 #include "CegoBufferPool.h"
-#include "CegoDistDbHandler.h"
+#include "CegoDbHandler.h"
 #include "CegoQueryCache.h"
 #include "CegoTableCache.h"
 #include "CegoDefs.h"
 
+class CegoTableManager;
+
 class CegoDatabaseManager : public CegoBufferPool {
     
  public:
@@ -60,21 +62,12 @@ class CegoDatabaseManager : public CegoBufferPool {
     
     void startRecovery(const Chain& tableSet);
 
-    void startCopy(const Chain& tableSet, 
-		   const Chain& targetHost, 
-		   const Chain& mediatorHost, 
-		   const Chain& user, 
-		   const Chain& passwd,
-		   const Chain& msg);
-
     RecoveryMode getRecoveryMode(unsigned tabSetId);
     void setRecoveryMode(unsigned tabSetId, RecoveryMode m);
 
     void setAllRecoveryOff();
 
     bool nextRecovery(Chain& tableSet);
-    bool nextCopy(unsigned &id, Chain& tableSet, Chain& targetHost, Chain& mediatorHost, Chain& user, Chain& passwd);
-    void setCopyStatus(unsigned id, const Chain& msg);
 
     void addObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type);
 
@@ -88,8 +81,8 @@ class CegoDatabaseManager : public CegoBufferPool {
     
     void printObjectList();
 
-    void setThreadInfo(unsigned numDbThread, unsigned numAdmThread, unsigned numLogThread);
-    void getThreadInfo(unsigned& numDbThread, unsigned& numAdmThread, unsigned& numLogThread,
+    void setThreadInfo(unsigned numDbThread, unsigned numAdmThread);
+    void getThreadInfo(unsigned& numDbThread, unsigned& numAdmThread,
 		       unsigned& activeDbThread, unsigned& activeAdmThread, unsigned& activeLogThread);
     
     void increaseActiveAdmThread();
@@ -98,18 +91,9 @@ class CegoDatabaseManager : public CegoBufferPool {
     void increaseActiveDbThread();
     void decreaseActiveDbThread();
 
-    void increaseActiveLogThread();
-    void decreaseActiveLogThread();
 
     void getDBMLockStat(Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay);
 
-    CegoDistDbHandler* allocateSession(const Chain& hostName, const Chain& tableSet, 
-				       const Chain& userName, const Chain& password);
-    void releaseSession(CegoDistDbHandler* pSH);
-    void cleanSession(unsigned lifetime);
-    
-    Element* getSessionInfo(unsigned lifetime);
-    Element* getCopyInfo();
 
     void configureLogger();
 
@@ -133,10 +117,6 @@ class CegoDatabaseManager : public CegoBufferPool {
     
 private:
 
-    CegoDistDbHandler* createSession(const Chain& hostName, const Chain& tableSet,
-				     const Chain& userName, const Chain& password);
-
-    void closeSession(CegoDistDbHandler* pSH);
 
     void PR();
     void PW();
@@ -187,103 +167,17 @@ private:
 	unsigned long long _tid;
     };
 
-    class CopyRecord {
-	
-    public:
-	
-	CopyRecord();
-	CopyRecord(const Chain& tableSet, const Chain& targetHost, const Chain& mediatorHost, const Chain& user, const Chain& passwd, const Chain& msg);
-	~CopyRecord();
-
-	unsigned getId() const;
-	void setId(unsigned id);
-
-	const Chain& getTableSet() const;
-	const Chain& getTargetHost() const;
-	const Chain& getMediatorHost() const;
-	
-	const Chain& getUser() const;
-	const Chain& getPasswd() const;
-	
-	void setMsg(const Chain& msg);
-	const Chain& getMsg() const;
-
-	CopyRecord& operator = ( const CopyRecord& cr);
-        bool operator == ( const CopyRecord& cr);
-	
-	friend ostream& operator << (ostream& s, const CopyRecord& cr)
-	{
-	    s << "(" << cr._tableSet << "," << cr._targetHost << "," << cr._mediatorHost << ","  << cr._user << "," << cr._passwd << ")";
-	    return s;
-	}
-
-    private:
-
-	unsigned _id;
-	Chain _tableSet;
-	Chain _targetHost;
-	Chain _mediatorHost;
-
-	Chain _user;
-	Chain _passwd;	
-	Chain _msg;
-    };
-
-    class DbSessionRecord {
-	
-    public:
-	
-	DbSessionRecord();
-	DbSessionRecord(CegoDistDbHandler* pHandler);
-	DbSessionRecord(const Chain& hostName, const Chain& tableSet, const Chain& userName, CegoDistDbHandler* pHandler);
-	~DbSessionRecord();
-
-	const Chain& getHostName() const;
-	const Chain& getTableSet() const;
-	const Chain& getUserName() const;
-
-	bool isUsed() const;
-	void setUsed(bool isUsed);
-	long long getTSLastUsed();
-	void setTSLastUsed(long long ts);
-
-	CegoDistDbHandler* getDbHandler() const;
-
-	DbSessionRecord& operator = ( const DbSessionRecord& sr);
-        bool operator == ( const DbSessionRecord& sr);
-	
-	friend ostream& operator << (ostream& s, const DbSessionRecord& sr)
-	{
-	    s << "(" << sr._tableSet << "," << sr._hostName << ")";
-	    return s;
-	}
-
-    private:
-
-	Chain _hostName;
-	Chain _tableSet;
-	Chain _userName;
-	long long _lastUsed;
-	bool _isUsed;
-	CegoDistDbHandler* _pHandler;
-    };
 
     ListT<ObjectRecord> _objList;
-    ListT<CopyRecord> _copyList;
-    ListT<DbSessionRecord> _dbSessionList;
 
     RecoveryMode _recoveryMode[TABMNG_MAXTABSET];
     ListT<Chain> _recoveryList;
     
     unsigned _numDbThread;
     unsigned _numAdmThread;
-    unsigned _numLogThread;
 
     unsigned _activeDbThread;
     unsigned _activeAdmThread;
-    unsigned _activeLogThread;
-
-    unsigned _nextCopyId;
 
     CegoDbHandler::ProtocolType _protType;
 
