@@ -55,7 +55,7 @@ CegoDbThread::CegoDbThread(CegoDbThreadPool *pPool, CegoDatabaseManager *pDBMng,
 
     histLock.init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
 
-    _pTabMng = new CegoDistManager(_pDBMng);
+    _pTabMng = new CegoQueryManager(_pDBMng);
     _pPA = new CegoAction(_pTabMng, _pPool);
 
     _pTim = new NanoTimer();
@@ -211,10 +211,10 @@ void* CegoDbThread::job(void* arg)
 		    
 		    _pDBMng->increaseActiveDbThread();
 		    
-		    CegoDistDbHandler *pSH = 0;
+		    CegoDbHandler *pSH = 0;
 		    try
 		    {	       	
-			pSH = new CegoDistDbHandler(pRequest, _protType, _pDBMng); 
+			pSH = new CegoDbHandler(pRequest, _protType, _pDBMng); 
 			serveSession(pSH);
 			delete pSH;
 		    }
@@ -237,7 +237,7 @@ void* CegoDbThread::job(void* arg)
 		    }
 		    
 		    // in any case, rollback any open transactions
-		    _pTabMng->rollbackDistTransaction(_pPA->getTableSet());
+		    _pTabMng->rollbackTransaction(_pPA->getTableSet());
 		    
 		    _pDBMng->decreaseActiveDbThread();		    
 #ifdef CGDEBUG
@@ -389,7 +389,7 @@ void CegoDbThread::invalidateObject(unsigned tabSetId, const Chain& objName, Ceg
     }    
 }
 
-void CegoDbThread::serveSession(CegoDistDbHandler *pSH)
+void CegoDbThread::serveSession(CegoDbHandler *pSH)
 {       
 #ifdef CGDEBUG
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Thread ") + Chain(_idx) + Chain(" : Serving session"));
@@ -475,7 +475,7 @@ void CegoDbThread::serveSession(CegoDistDbHandler *pSH)
     }
 }
 
-bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestType reqType)
+bool CegoDbThread::serveRequest(CegoDbHandler *pSH, CegoDbHandler::RequestType reqType)
 {
 
     Chain tsState = _pDBMng->getTableSetRunState(pSH->getTableSet());
@@ -536,428 +536,6 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 #endif   
 	    break;
 	}
-	case CegoDbHandler::INSERT:
-	{
-	    Chain tableSet;
-	    Chain tableName;
-	    ListT<CegoField> fl;
-	    
-	    pSH->getInsertArg(tableSet, tableName,fl);
-	    
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    
-	    CegoTableObject oe;
-	    _pTabMng->getObject(tabSetId, tableName, CegoObject::TABLE, oe);
-	    _pTabMng->insertLocalDataTable(oe, fl);
-	    
-	    pSH->sendResponse(Chain("insert ok"));	    
-	    break;
-	}
-	case CegoDbHandler::DELETETABLE:
-	{
-	    /*
-	    Chain tableSet;
-	    Chain tableName;
-	    CegoPredDesc *pPred = 0;
-	    
-	    pSH->getDeleteArg(tableSet, tableName, pPred, _pTabMng);
-	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
-	    
-	    CegoTableObject oe;
-	    _pTabMng->getObject(tabSetId, tableName, CegoObject::TABLE, oe);
-	    
-	    unsigned long long delCount = _pTabMng->deleteLocalDataTable(oe, pPred);
-	    	    
-	    pSH->sendResponse(Chain("delete ok"), delCount);
-	    */
-	    
-	    break;
-	}
-	case CegoDbHandler::UPDATE:
-	{
-	    /*
-	    Chain tableSet;
-	    Chain tableName;
-	    CegoPredDesc *pPred = 0;
-	    ListT<CegoField> updSchema;
-	    ListT<CegoExpr*> exprList;
-	    
-	    pSH->getUpdateArg(tableSet, tableName, updSchema, exprList, pPred, _pTabMng);
-	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);
-	    
-	    CegoTableObject oe;
-	    _pTabMng->getObject(tabSetId, tableName, CegoObject::TABLE, oe);
-
-	    bool returnOnFirst = false; // still not supported
-	    ListT<CegoField> returnList;
-	    unsigned long long updCount = _pTabMng->updateLocalDataTable(oe, pPred, updSchema, exprList, returnOnFirst, returnList);
-	    
-	    pSH->sendResponse(Chain("update ok"), updCount);
-	    */   
-	    break;
-	}
-	case CegoDbHandler::CREATETABLE:
-	{	    
-	    Chain tableSet;
-	    Chain tableName;
-	    ListT<CegoField> fl;
-	    ListT<CegoField> idxList;
-	    
-	    pSH->getCreateTableArg(tableSet, tableName, fl, idxList);
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	    
-	    _pTabMng->createLocalDataTable(tabSetId, tableName, CegoObject::TABLE, fl, idxList);	  	    
-
-	    _pDBMng->addObject(tabSetId, tableName, CegoObject::TABLE); 
-	    if ( ! idxList.isEmpty() )
-	    {
-		Chain idxName = tableName + Chain(TABMNG_PIDX_SUFFIX);	
-		_pDBMng->addObject(tabSetId, idxName, CegoObject::AVLTREE);	
-	    }
-
-	    pSH->sendResponse(Chain("create ok"));	    
-	    break;	    
-	}
-	case CegoDbHandler::CREATEVIEW:
-	{	    
-	    Chain tableSet;
-	    Chain viewName;
-	    Chain viewText;
-	    ListT<CegoField> fl;
-	    
-	    pSH->getCreateViewArg(tableSet, viewName, fl, viewText);
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	    
-	    _pTabMng->createLocalView(tabSetId, viewName, fl, viewText);	  	    
-
-	    _pDBMng->addObject(tabSetId, viewName, CegoObject::VIEW);
-
-	    pSH->sendResponse(Chain("create view ok"));	    
-	    break;	    
-	}
-	case CegoDbHandler::CREATEPROCEDURE:
-	{	    
-	    Chain tableSet;
-	    Chain procName;
-	    Chain procText;
-	    
-	    pSH->getCreateProcedureArg(tableSet, procName, procText);
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	    
-	    _pTabMng->createLocalProc(tabSetId, procName, procText);	  	    
-
-	    _pDBMng->addObject(tabSetId, procName, CegoObject::PROCEDURE);
-
-	    pSH->sendResponse(Chain("create procedure ok"));	    
-	    break;	    
-	}
-	/*
-           CREATECHECK and ALTERTABLE actually no more supported, since 
-           the required XML emcoding for CegoPredDesc is deprecated.
-           For distributed mode, also fast serial protocol needs support
-	*/
-	case CegoDbHandler::CREATECHECK:
-	{
-	    /*
-	    Chain tableSet;
-	    Chain checkName;
-	    Chain tableName;
-	    CegoPredDesc *pPred;
-
-	    pSH->getCreateCheckArg(tableSet, checkName, tableName, pPred, _pTabMng);
-	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);	    
-	    _pTabMng->createLocalCheck(tabSetId, checkName, tableName, pPred);	  	    
-
-	    _pDBMng->addObject(tabSetId, checkName, CegoObject::CHECK);
-
-	    pSH->sendResponse(Chain("create check ok"));	    
-	    */
-	    
-	    break;	    
-	}
-
-	case CegoDbHandler::ALTERTABLE:
-	{
-	    /*
-	    Chain tableSet;
-	    Chain tableName;
-	    ListT<CegoAlterDesc> alterList;
-	    
-	    pSH->getAlterTableArg(tableSet, tableName, alterList);	    
-	    int tabSetId = _pDBMng->getTabSetId(tableSet);	    
-	    _pTabMng->alterDataTable(tabSetId, tableName, CegoObject::TABLE, alterList);	    
-	    pSH->sendResponse(Chain("alter ok"));	    
-	    */
-	    break;
-	}
-       
-	case CegoDbHandler::DROPOBJECT:
-	{	    
-	    Chain tableSet;
-	    CegoObject::ObjectType objType; 
-	    Chain objName;
-	    
-	    pSH->getDropTableArg(tableSet, objName, objType);	    
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    _pTabMng->dropObjectSynced(tabSetId, objName, objType);
-	    pSH->sendResponse(Chain("Drop ok"));	    
-	    break;	    
-	}
-	case CegoDbHandler::CREATEINDEX:
-	{	    
-	    Chain tableSet;
-	    Chain indexName;
-	    Chain tableName;
-	    ListT<CegoField> idxList;
-	    CegoObject::ObjectType type;	    
-	    pSH->getCreateIndexArg(tableSet, indexName, tableName, idxList, type);	    
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-
-	    bool isCached = false;
-	    _pTabMng->createIndexTableSynced(tabSetId, indexName, tableName, type, idxList, isCached);
-
-	    _pDBMng->addObject(tabSetId, indexName, type);
-
-	    pSH->sendResponse(Chain("create ok"));	    
-	    break;	    
-	}
-	case CegoDbHandler::OBJECTINFO:
-	{
-	    unsigned tabSetId;
-	    Chain objName;
-	    CegoObject::ObjectType objType;
-	    
-	    pSH->getObjectInfoArg(tabSetId, objName, objType);
-	    
-	    if ( _pDBMng->objectExists(tabSetId, objName, objType) == false )
-		pSH->sendError(Chain("Object does not exist"));
-	    else
-	    {	 
-		switch ( objType )
-		{
-		case CegoObject::SYSTEM:
-		case CegoObject::TABLE:
-		case CegoObject::PAVLTREE:
-		case CegoObject::UAVLTREE:
-		case CegoObject::AVLTREE:
-		{   
-		    CegoTableObject to;
-		    _pTabMng->getLocalObject(tabSetId, objName, objType, to);
-		    pSH->sendObjInfo(to);
-		    break;
-		}
-		case CegoObject::BTREE:
-		case CegoObject::PBTREE:
-		case CegoObject::UBTREE:
-		{   
-		    CegoBTreeObject bto;
-		    _pTabMng->getLocalObject(tabSetId, objName, objType, bto);
-		    pSH->sendObjInfo(bto);
-		    break;
-		}
-		case CegoObject::VIEW:
-		{
-		    CegoViewObject vo;
-		    _pTabMng->getLocalObject(tabSetId, objName, objType, vo);
-		    pSH->sendObjInfo(vo);
-		    break;
-		}
-		case CegoObject::PROCEDURE:
-		{
-		    CegoProcObject po;
-		    _pTabMng->getLocalObject(tabSetId, objName, objType, po);
-		    pSH->sendObjInfo(po);
-		    break;
-		}
-		case CegoObject::FKEY:
-		{
-		    CegoKeyObject ko;
-		    _pTabMng->getLocalObject(tabSetId, objName, objType, ko);
-		    pSH->sendObjInfo(ko);
-		    break;
-		}
-		case CegoObject::CHECK:
-		{
-		    CegoCheckObject co;
-		    _pTabMng->getLocalObject(tabSetId, objName, objType, co);
-		    pSH->sendObjInfo(co);
-		    break;
-		}
-		case CegoObject::TRIGGER:
-		{
-		    CegoTriggerObject to;
-		    _pTabMng->getLocalObject(tabSetId, objName, objType, to);
-		    pSH->sendObjInfo(to);
-		    break;
-		}
-		case CegoObject::ALIAS:
-		{
-		    CegoAliasObject ao;
-		    _pTabMng->getLocalObject(tabSetId, objName, objType, ao);
-		    pSH->sendObjInfo(ao);
-		    break;
-		}
-		case CegoObject::JOIN:
-		case CegoObject::RBSEG:
-		case CegoObject::UNDEFINED:
-		{
-		    throw Exception(EXLOC, "Objectinfo not supported for this object type");
-		    break;
-		}
-		}
-	    }
-	    break;
-	}
-	case CegoDbHandler::GETTABLE:
-	{
-	    unsigned tabSetId;
-	    Chain tableName;
-	    CegoObject::ObjectType type;
-	    
-	    pSH->getGetTableArg(tabSetId, tableName, type);
-	    
-	    CegoTableObject oe;
-	    _pTabMng->getLocalObject(tabSetId, tableName, type, oe);
-	    
-	    ListT<CegoField> schema = oe.getSchema();		
-	    
-	    pSH->collectSchema(schema);
-	    
-	    CegoObjectCursor *pOC = _pTabMng->getObjectCursor(tabSetId, tableName, tableName, type);
-	    
-	    unsigned tupleCount=0;
-	    
-	    CegoDataPointer dp;
-	    bool moreTuple = _pTabMng->getFirstTuple(pOC, schema, dp);
-	    
-	    while ( moreTuple )
-	    {
-		pSH->collectData(schema);
-		tupleCount++;
-		
-		if ( tupleCount == NETMNG_MAXTUPLECOUNT )
-		{
-		    pSH->sendCollectedData();
-		    tupleCount=0;
-		}
-		moreTuple = _pTabMng->getNextTuple(pOC, schema, dp);
-	    }
-	    
-	    if ( tupleCount > 0)
-	    {
-		pSH->sendCollectedData();
-	    }
-	    
-	    pSH->sendFinishData();
-	 	    
-	    break;
-	}
-	case CegoDbHandler::GETOBJLIST:
-	{
-	    unsigned tabSetId;
-	    CegoObject::ObjectType type;
-	    
-	    pSH->getGetObjectListArg(tabSetId, type);
-	    
-	    ListT<Chain> objList;
-	    _pTabMng->getObjectList(tabSetId, type, objList);
-	    
-	    pSH->sendObjList(objList);
-	    
-	    break;
-	}
-	case CegoDbHandler::GETOBJLISTBYTABLE:
-	{
-	    Chain tableSet;
-	    Chain tableName;
-	    
-	    pSH->getGetObjectByTableListArg(tableSet, tableName);
-	    
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    
-	    
-	    ListT<CegoTableObject> idxList;
-	    ListT<CegoBTreeObject> btreeList;
-	    ListT<CegoKeyObject> keyList;
-	    ListT<CegoCheckObject> checkList;
-	    ListT<CegoTriggerObject> triggerList;
-	    ListT<CegoAliasObject> aliasList;
-	    unsigned numInvalid;
-
-	    _pTabMng->setIgnoreInvalid(false);
-	    _pTabMng->getObjectListByTable(tabSetId, tableName, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
-	    
-	    pSH->sendObjByTableList(idxList, keyList, checkList);
-	    
-	    break;
-	}	
-	case CegoDbHandler::OBJRENAME:
-	{
-	    Chain tableSet;
-	    CegoObject::ObjectType type;
-	    Chain objName;
-	    Chain newObjName;
-	    
-	    pSH->getRenameArg(tableSet, objName, type, newObjName);
-	    
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    
-	    _pTabMng->renameObject(tabSetId, objName, type, newObjName);
-	    
-	    pSH->sendResponse(Chain("rename ok"));
-	    
-	    break;
-	}
-	case CegoDbHandler::REORGOBJ:
-	{
-	    Chain tableSet;
-	    CegoObject::ObjectType type;
-	    Chain objName;
-	    Chain newObjName;
-	    
-	    pSH->getReorgArg(tableSet, objName, type);
-	    
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    
-	    _pTabMng->reorgObject(tabSetId, objName, type);
-	    
-	    pSH->sendResponse(Chain("reorg ok"));
-	    
-	    break;	   
-	}
-	case CegoDbHandler::SYNC:
-	{
-	    Chain tableSet;
-	    Chain escCmd;
-	    unsigned timeout;
-	    
-	    pSH->getSyncArg(tableSet, escCmd, timeout);
-	    
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    
-	    _pDBMng->writeCheckPoint(tabSetId, true, true, _pTabMng->getLockHandle(), escCmd, timeout );
-	    
-	    pSH->sendResponse(Chain("sync ok"));
-	    
-	    break;	    
-	}
-	case CegoDbHandler::GETPAGECOUNT:
-	{
-	    Chain tableSet;
-	    Chain objName;
-	    CegoObject::ObjectType type;
-	    
-	    pSH->getPageCountArg(tableSet, objName, type);
-	    
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    
-	    unsigned pageCount = 0;
-	    _pTabMng->getPageCount(tabSetId, objName, type);
-	    
-	    pSH->sendPageCount(pageCount);
-	    
-	    break;	    
-	}
 	case CegoDbHandler::PUTBLOB:
 	{
 	    _lastAction = Chain("put blob");
@@ -1436,50 +1014,6 @@ bool CegoDbThread::serveRequest(CegoDistDbHandler *pSH, CegoDbHandler::RequestTy
 	    
 	    break;   
 	}
-	case CegoDbHandler::STARTTRANSACTION:
-	{
-	    _lastAction = Chain("start transaction");
-	    
-	    Chain tableSet;
-	    pSH->getArgValue(XML_TABLESET_ATTR, tableSet);
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    _pTabMng->beginTransaction(tabSetId, true);
-	    pSH->sendResponse(Chain("Transaction started"));	    
-	    break;	    
-	}
-	case CegoDbHandler::COMMITTRANSACTION:
-	{
-	    _lastAction = Chain("commit transaction");
-	    
-	    Chain tableSet;
-	    pSH->getArgValue(XML_TABLESET_ATTR, tableSet);
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    _pTabMng->commitTransaction(tabSetId, true);
-	    pSH->sendResponse(Chain("Transaction committed"));
-			
-	    break;	    
-	}
-	case CegoDbHandler::ROLLBACKTRANSACTION:
-	{
-	    _lastAction = Chain("rollback transaction");
-	    
-	    Chain tableSet;
-	    pSH->getArgValue(XML_TABLESET_ATTR, tableSet);
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
-	    _pTabMng->rollbackTransaction(tabSetId, true);
-	    pSH->sendResponse(Chain("Transaction rollbacked"));			
-	    break;	    
-	}
-	case CegoDbHandler::GETTID:
-	{
-	    _lastAction = Chain("get tid");
-	    
-	    Chain tableSet;
-	    pSH->getArgValue(XML_TABLESET_ATTR, tableSet);
-	    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);	    
-	    pSH->sendTID(_pTabMng->getTID(tabSetId));	    
-	    break;	    
-	}
 	case CegoDbHandler::SESSION_CLOSE:
 	{
 	    _lastAction = Chain("close session");
