@@ -37,7 +37,7 @@ public:
     
     CegoException execute();
     void cleanUp();
-    Chain toChain(int defTabSetId, const Chain& indent = Chain("")) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent = Chain("")) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     bool isStatic() const;
     
