@@ -29,12 +29,11 @@
 #include "CegoRecoveryManager.h"
 #include "CegoPredicate.h"
 
-CegoRecoveryManager::CegoRecoveryManager(CegoDistManager *pGTM, CegoRecoveryManager::RecoveryMode mode)
+CegoRecoveryManager::CegoRecoveryManager(CegoQueryManager *pGTM)
 {
     _pGTM = pGTM;
     _pLogger = _pGTM->getDBMng();
     _pDBMng = _pGTM->getDBMng();
-    _recoveryMode = mode;
     _modId = _pDBMng->getModId("CegoRecoveryManager");
 }
 
@@ -42,6 +41,155 @@ CegoRecoveryManager::~CegoRecoveryManager()
 {
 }
 
+unsigned long long CegoRecoveryManager::startRecovery(const Chain& tableSet)
+{
+
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
+
+    _pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::ON);
+
+    Chain tsTicketName = _pDBMng->getTSTicket(tableSet);
+    
+    File tsTicket(tsTicketName);
+    if ( tsTicket.exists() ) 
+    {
+	tsTicket.open(File::READ);
+	
+	XMLSuite xml;
+	
+	Document *pDoc = new Document;
+	pDoc->setAttribute(XML_VERSION_ATTR, XML_VERSION_VALUE);
+	
+	xml.setDocument(pDoc);    
+	xml.setFile(&tsTicket);
+	
+	xml.parse();
+	
+	Element *pRoot = pDoc->getRootElement();
+	pDoc->setRootElement(0);
+	delete pDoc;
+		
+	_pDBMng->setTableSetInfo(tableSet, pRoot);
+	
+	tsTicket.close();
+    
+#ifdef CGDEBUG	
+	_pDBMng->log(_modId, Logger::DEBUG, Chain("Removing backup ticket ") + tsTicket.getFileName() + Chain(" ..."));
+#endif
+	    
+	tsTicket.remove();
+	
+	// after ticket restore, we have to set tabSetId to current tableset value
+	tabSetId = _pDBMng->getTabSetId(tableSet);
+    }
+
+    // we have to set tableset run state AFTER ticket restore
+    _pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
+   
+    _pDBMng->releaseLogFiles(tableSet, true);
+	
+    // during recovery, we do not write to online log files
+    _pDBMng->stopLog(tabSetId);	
+
+    _pGTM->regDataFiles(tableSet);
+
+    _pDBMng->adjustPageOffset();
+           
+    _pGTM->registerObjects(tableSet);
+
+
+    unsigned long long cplsn  = _pDBMng->getCommittedLSN(tableSet);	
+    _pDBMng->log(_modId, Logger::NOTICE, Chain("Committed lsn = ") + Chain(cplsn));
+    
+    cplsn++;
+        
+    while ( _pDBMng->getRecoveryMode(tabSetId) != CegoDatabaseManager::REQOFF )
+    {
+		
+	unsigned long long lsn = _pDBMng->getCommittedLSN(tableSet);
+	lsn++;
+	Chain archLogFile = _pDBMng->getArchiveLogName(tableSet, lsn);
+		
+	ListT<Chain> archIdList;
+	ListT<Chain> archPathList;
+	
+	_pDBMng->getArchLogInfo(tabSetId, archIdList, archPathList);
+	
+	Chain *pArchLogPath = archPathList.First();
+
+	bool fileFound = false;
+
+	Chain sourceFileName;
+	
+	while ( pArchLogPath  && fileFound == false)
+	{
+	    sourceFileName = *pArchLogPath + Chain("/") + archLogFile;
+	    
+	    File checkFile(sourceFileName);
+	    
+	    _pDBMng->log(_modId, Logger::NOTICE, Chain("Checking logfile ") + sourceFileName + Chain(" ..."));
+	    
+	    if ( checkFile.exists() )
+	    {		    
+		fileFound = true;		    
+	    }
+	    else
+	    {
+		pArchLogPath = archPathList.Next();
+	    }
+	}
+	    
+	// if we found the appropriate file, we try to recover it
+	if ( fileFound )
+	{
+
+	    _pDBMng->log(_modId, Logger::NOTICE, Chain("Recovering offline logfile ") + sourceFileName + Chain(" ..."));
+	    _pDBMng->setLogFile(tabSetId, sourceFileName, true);		
+	    	    
+	    unsigned long long lsn = 0;
+	    long long ts = 0;
+	    RecoveryState rstate = recoverCurrentTransactionLog(tabSetId, 0, 0, lsn, ts);
+	    
+	    // set current lsn
+	    _pDBMng->setCurrentLSN(tabSetId, lsn);
+
+	    cplsn = lsn;
+	    
+	    // skip to next expected lsn
+	    lsn++;
+	    
+	    if ( rstate == CegoRecoveryManager::RECOK )
+	    {
+		_pDBMng->log(_modId, Logger::NOTICE, Chain("Transaction recovery ok"));
+	    }
+	    else if ( rstate == CegoRecoveryManager::RECPITREACHED )
+	    {	      
+		_pDBMng->log(_modId, Logger::NOTICE, Chain("PIT reached"));
+	    }
+	    else
+	    {
+		throw Exception(EXLOC, Chain("Unknwon recovery state"));
+	    }
+	    
+	    _pDBMng->writeCheckPoint(tableSet, false, false, _pGTM->getLockHandle());
+	}
+	else
+	{	
+	    Sleeper s;
+	    s.secSleep(LOGMNG_RECOVERY_DELAY);
+	}
+    }
+
+    // if recovery is finished, we still have to initialize online redo logs
+    _pDBMng->initLogFiles(tableSet, true);
+
+    
+    _pDBMng->setTableSetRunState(tableSet, XML_OFFLINE_VALUE);
+    _pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::OFF);
+
+    return cplsn;
+}
+    
 unsigned long long CegoRecoveryManager::recoverTableSet(const Chain& tableSet, long long pit, unsigned long long targetlsn, CegoAdminHandler* pAH)
 {   
     _pLogger->log(_modId, Logger::NOTICE, Chain("Recovering tableset ") + tableSet + Chain(" ..."));
@@ -58,42 +206,21 @@ unsigned long long CegoRecoveryManager::recoverTableSet(const Chain& tableSet, l
     
     unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
-    _pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
-    _pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::ON ); 
 
     try
     {	
-	while ( _pDBMng->getTableSetSyncState(tableSet) != Chain(XML_SYNCHED_VALUE) &&  _pDBMng->getRecoveryMode(tabSetId) == CegoDatabaseManager::ON)
-	{
-#ifdef CGDEBUG	
-	    _pDBMng->log(_modId, Logger::DEBUG, Chain("Waiting for tableset sync ... "));
-#endif
-	    
-	    Sleeper s;
-	    s.secSleep(LOGMNG_RECOVERY_DELAY);
-	}
-	
-	if ( _pDBMng->getTableSetSyncState(tableSet) != Chain(XML_SYNCHED_VALUE) )
-	{
-	    Chain msg = Chain("No sync on tableset ") + tableSet + Chain(", recovery failed");
-	    _pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::OFF );
-	    _pDBMng->log(_modId, Logger::LOGERR, msg);
-	    throw Exception(EXLOC, msg); 
-	}
 		
-	// release online logfiles to force archiving
-	if ( _recoveryMode == LOCAL )
-	{
-	    if ( pAH ) 
-		pAH->syncWithInfo(Chain("local"), Chain("local"), Chain("Releasing log files ...\n")); 
-	    _pDBMng->releaseLogFiles(tableSet, true);
-	}
+	if ( pAH ) 
+	    pAH->syncWithInfo(Chain("local"), Chain("local"), Chain("Releasing log files ...\n")); 
+	_pDBMng->releaseLogFiles(tableSet, true);
+	
 
 	// during recovery, we do not write to online log files
 	if ( pAH ) 
             pAH->syncWithInfo(Chain("local"), Chain("local"), Chain("Stopping log ...\n")); 
 	_pDBMng->stopLog(tabSetId);	
-	
+
+		
 	Chain tsTicketName = _pDBMng->getTSTicket(tableSet);
 
 	bool needFileRecovery=false;
@@ -133,7 +260,7 @@ unsigned long long CegoRecoveryManager::recoverTableSet(const Chain& tableSet, l
 			
 		Chain msg = Chain("Backup branch mismatch : <") + buId + Chain("> != <") + currentId + Chain(">");
 		
-		_pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::OFF );
+		// _pDBMng->setRecoveryMode(tabSetId, CegoDatabaseManager::OFF );
 		_pDBMng->log(_modId, Logger::LOGERR, msg);
 		
 		throw Exception(EXLOC, msg);
@@ -153,6 +280,8 @@ unsigned long long CegoRecoveryManager::recoverTableSet(const Chain& tableSet, l
 	    tabSetId = _pDBMng->getTabSetId(tableSet);
 	}
 
+	// we have to set tableset run state AFTER ticket restore
+	_pDBMng->setTableSetRunState(tableSet, XML_RECOVERY_VALUE);
 	
 	// register data files, this is also needed for data file recovery
 	
@@ -289,7 +418,7 @@ unsigned long long CegoRecoveryManager::dataFileRecovery(const Chain& tableSet,
     bool endOfBackup = false;   
     unsigned long long lsn = cplsn;
 
-    while ( endOfBackup == false &&  _pDBMng->getRecoveryMode(tabSetId) == CegoDatabaseManager::ON )
+    while ( endOfBackup == false )
     {	
 	Chain archLogFileName = _pDBMng->getArchiveLogName(tableSet, lsn);
 	
@@ -336,16 +465,11 @@ unsigned long long CegoRecoveryManager::dataFileRecovery(const Chain& tableSet,
 	    lsn++;
 	    
 	}
-	else if ( _recoveryMode == LOCAL )
+	else
 	{
 	    if  ( restoreLogFile(tableSet, lsn) == false)
 		endOfBackup = true;
 	}
-	else
-	{
-	    Sleeper s;
-	    s.secSleep(LOGMNG_RECOVERY_DELAY);	    
-	}
     }
 
     return lsn;
@@ -359,13 +483,12 @@ unsigned long long CegoRecoveryManager::transactionRecovery(const Chain& tableSe
     unsigned long long lsn = cplsn;
     RecoveryState rstate = CegoRecoveryManager::RECOK;
      
-    while ( _pDBMng->getRecoveryMode(tabSetId) == CegoDatabaseManager::ON 
-	    && rstate != CegoRecoveryManager::RECPITREACHED
+    while ( rstate != CegoRecoveryManager::RECPITREACHED
 	    && endOfRecovery == false)
     {	
 	bool fileFound = false;   
 
-	while ( fileFound == false && endOfRecovery == false &&  _pDBMng->getRecoveryMode(tabSetId) == CegoDatabaseManager::ON )
+	while ( fileFound == false && endOfRecovery == false ) 
 	{	    
 	    Chain archLogFileName = _pDBMng->getArchiveLogName(tableSet, lsn);
 	    
@@ -394,7 +517,7 @@ unsigned long long CegoRecoveryManager::transactionRecovery(const Chain& tableSe
 		}
 	    }
 	    
-	    if ( fileFound == false && _recoveryMode == LOCAL)
+	    if ( fileFound == false )
 	    {
 		if  ( restoreLogFile(tableSet, lsn) == false)
 		    endOfRecovery = true;		
@@ -410,7 +533,7 @@ unsigned long long CegoRecoveryManager::transactionRecovery(const Chain& tableSe
 	if ( fileFound )
 	{
 	    bool isRecovered = false;
-	    while ( ! isRecovered  && _pDBMng->getRecoveryMode(tabSetId) == CegoDatabaseManager::ON )
+	    while ( ! isRecovered ) 
 	    {		
 		_pDBMng->log(_modId, Logger::NOTICE, Chain("Recovering offline logfile ") + sourceFileName + Chain(" ..."));
 		_pDBMng->setLogFile(tabSetId, sourceFileName, true);		
@@ -763,13 +886,13 @@ CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactio
 	    case CegoLogRecord::LOGREC_COMMIT:
 	    {
 		_pGTM->setTID(tabSetId, tid);	    
-		_pGTM->commitTransaction(tabSetId, false);
+		_pGTM->commitTableTransaction(tabSetId, false);
 		break;
 	    }
 	    case CegoLogRecord::LOGREC_ABORT:
 	    {
 		_pGTM->setTID(tabSetId, tid);
-		_pGTM->rollbackTransaction(tabSetId, false);
+		_pGTM->rollbackTableTransaction(tabSetId, false);
 		break;
 	    }
 	    case CegoLogRecord::LOGREC_INSERT:
