@@ -34,7 +34,6 @@
 #include "CegoPredicate.h"
 #include "CegoQueryHelper.h"
 #include "CegoLockHandler.h"
-#include "CegoTransactionManager.h"
 #include "CegoAlterDesc.h"
 #include "CegoDefs.h"
 #include "CegoProcedure.h"
@@ -42,9 +41,10 @@
 #include "CegoSystemObject.h"
 #include "CegoBTreeValue.h"
 #include "CegoTrigger.h"
+#include "CegoObjectCursor.h"
 
-class CegoTransactionManager;
 class CegoDbThreadPool;
+class CegoTransactionManager;
 
 class CegoTableManager : public CegoSystemObject {
 
@@ -67,7 +67,7 @@ public:
     void endBackup(const Chain& tableSet, const Chain&msg, bool keepTicket = true);
     void resetBUStat(const Chain& tableSet);
     void syncTableSet(const Chain& tableSet, const Chain& msg, const Chain& escCommand, unsigned timeout);
-    void logTo(const Chain& tableSet, const Chain& secondary);
+    // void logTo(const Chain& tableSet);
     void addDataFile(const Chain& tableSet, const Chain& type, unsigned fileId, const Chain& dataFile, unsigned fileSize);
     // transaction methods
     void setIsolationLevel(IsolationLevel level);
@@ -79,9 +79,9 @@ public:
     void beginTransaction(unsigned tabSetId, bool doLog);
     void getTransactionAffectedTables(unsigned tabSetId, SetT<Chain>& tableList);
     unsigned long long commitTransactionSynced(unsigned tabSetId);
-    unsigned long long commitTransaction(unsigned tabSetId, bool doLog);
+    unsigned long long commitTableTransaction(unsigned tabSetId, bool doLog);
+    unsigned long long rollbackTableTransaction(unsigned tabSetId, bool doLog);
     unsigned long long rollbackTransactionSynced(unsigned tabSetId);
-    unsigned long long rollbackTransaction(unsigned tabSetId, bool doLog);
     unsigned long long getTID(unsigned tabSetId);
     void setTAStep(unsigned tabSetId, unsigned long long tastep);
     unsigned long long getTAStep(unsigned tabSetId);
@@ -226,7 +226,8 @@ public:
     // debugging methods
     void dumpObject(const Chain& tableSet, const Chain& tableName, CegoObject::ObjectType type, Chain& chainDump);
     void dumpObject(unsigned tabSetId, const Chain& tableName, CegoObject::ObjectType type, Chain& chainDump);
-
+    void extractTicket(const Chain& tableSet);
+    
 protected:
 
     CegoTransactionManager *_pTM;
@@ -238,7 +239,8 @@ protected:
     bool _doAppend;
     
 private:
-    
+
+
     void renameTable(unsigned tabSetId, const Chain& tableName, const Chain& newTableName);
     void renameIndex(unsigned tabSetId, const Chain& idxName, CegoObject::ObjectType type, const Chain& newIdxName);
     void renameBTree(unsigned tabSetId, const Chain& btreeName, CegoObject::ObjectType type, const Chain& newBTreeName);
