@@ -35,8 +35,8 @@ public:
 
     CegoTriggerObject();
     CegoTriggerObject(const CegoTriggerObject& co);
-    CegoTriggerObject(ObjectType type,  const Chain& objName, int tabSetId = 0);
-    CegoTriggerObject(int tabSetId,
+    CegoTriggerObject(ObjectType type,  const Chain& objName, unsigned tabSetId = 0);
+    CegoTriggerObject(unsigned tabSetId,
 		      const Chain& triggerName,
 		      bool isBefore,
 		      bool isOnInsert,
@@ -58,7 +58,7 @@ public:
     const Chain& getTabName() const;
     void setTriggerText(const Chain& triggerText);   
     const Chain& getTriggerText() const;
-    int getEntrySize() const;
+    unsigned getEntrySize() const;
     void encode(char *buf) const;
     void decode(char *buf);
     Chain toChain() const;
