@@ -40,7 +40,7 @@ public:
 
     static Chain getTypeString(CegoDataType type);
     static CegoDataType getTypeId(const Chain& typeString);
-    static int getTypeLen(CegoDataType type, const Chain& val = Chain(""));
+    static unsigned getTypeLen(CegoDataType type, const Chain& val = Chain(""));
     static Chain getObjectTypeString(CegoObject::ObjectType type);
     static CegoObject::ObjectType getObjectTypeId(const Chain& typeString);
 };
