@@ -122,17 +122,6 @@ public:
     void incUserQuery(const Chain& user);
     Element* getUserList();
     Element* getRoleList();
-    Chain getPrimary(const unsigned tabSetId);
-    Chain getPrimary(const Chain& tabSetName);
-    Chain getSecondary(const unsigned tabSetId);
-    Chain getSecondary(const Chain& tabSetName);
-    Chain getMediator(const unsigned tabSetId);
-    Chain getMediator(const Chain& tabSetName);
-    void setPrimary(const Chain& tabSetName, const Chain& hostName);
-    void setSecondary(const Chain& tabSetName, const Chain& hostName);
-    void setMediator(const Chain& tabSetName, const Chain& hostName);
-    void getMedList(const Chain& hostname, ListT<Chain>& medList);
-    void getTSforMedAndPrim(const Chain& mediator, const Chain& primary, ListT<Chain>& tsList);
 
     unsigned getTabSetId(const Chain& tabSetName) const;
     Chain getTabSetName(unsigned tabSetId);
@@ -173,9 +162,6 @@ public:
     bool checkPointDumpEnabled(unsigned tabSetId);
     void addTableSetDef(const Chain& tabSetName,
 			const Chain& tsRoot,
-			const Chain& primary,
-			const Chain& secondary,
-			const Chain& mediator,
 			unsigned sysFileId, unsigned tempFileId, unsigned sysFileSize, unsigned tmpFileSize, unsigned appFileSize,
 			unsigned logFileSize, unsigned logFileNum, unsigned long long sortAreaSize, unsigned branchId);
     void rmTableSetDef(const Chain& tabSetName);
@@ -184,10 +170,8 @@ public:
     void getDataPort(unsigned& dataPort);
     void getAdminPort(unsigned& adminPort);
     void getLogPort(unsigned& logPort);
-    void getPidFile(Chain& pidFile);
     void setXmlDef(const Chain& xmlDef);
-    void initXml(const Chain& dbName, unsigned pageSize, const Chain& hostName, unsigned dbPort, unsigned admPort, unsigned logPort, const Chain& pidFile,
-		 const Chain& logLevel, const Chain& csmode, bool qescmode);
+    void initXml(const Chain& dbName, unsigned pageSize, const Chain& hostName, unsigned dbPort, unsigned admPort, unsigned logPort, const Chain& logLevel, const Chain& csmode, bool qescmode);
     void xml2Doc();
     void doc2Xml();
     void initDoc();
@@ -207,14 +191,13 @@ public:
     unsigned nextFID();
     unsigned nextTSID();
     void getAllActiveTableSet(ListT<Chain>& tsList);
-    void getActiveTableSet(const Chain& primary, ListT<Chain>& tsList, bool includeRecovery = true, bool includeOffline = false);
+    void getActiveTableSet(ListT<Chain>& tsList, bool includeRecovery = true, bool includeOffline = false);
     ListT<unsigned> getOnlineTableSet() const;
     Chain getTableSetRunState(unsigned tabSetId);
     void setTableSetRunState(unsigned tabSetId, const Chain& status);
     Chain getTableSetRunState(const Chain& tableSet);
     void setTableSetRunState(const Chain& tableSet, const Chain& status);
-    Chain getTableSetSyncState(const Chain& tableSet);
-    void setTableSetSyncState(const Chain& tableSet, const Chain& status);
+
     void setCommittedLSN(unsigned tabSetId, unsigned long long lsn);
     void setCommittedLSN(const Chain& tableSet, unsigned long long lsn);
     unsigned long long getCommittedLSN(const Chain& tableSet);
