@@ -33,6 +33,7 @@
 #define XML_SESSION_CLOSE "CLOSE"
 
 // admin session requests
+#define XML_GET_TABLESETLIST_REQUEST "GET_TABLESETLIST"
 #define XML_RETRIEVETABLESET_REQUEST "RETRIEVETABLESET"
 #define XML_LOCKINFO_REQUEST "LOCKINFO"
 #define XML_LOCKSTAT_REQUEST "LOCKSTAT"
@@ -48,7 +49,6 @@
 #define XML_SETNUMQUERYLAST_REQUEST "SETNUMQUERYLAST"
 #define XML_SETNUMQUERYCOST_REQUEST "SETNUMQUERYCOST"
 #define XML_ADMTHREADINFO_REQUEST "ADMTHREADINFO"
-#define XML_LOGTHREADINFO_REQUEST "LOGTHREADINFO"
 #define XML_DBSESSIONINFO_REQUEST "DBSESSIONINFO"
 #define XML_COPYINFO_REQUEST "COPYINFO"
 #define XML_SHOWQUERYCACHE_REQUEST "SHOWQUERYCACHE"
@@ -76,14 +76,12 @@
 #define XML_GET_OBJECT_INFO_REQUEST "GET_OBJECT_INFO"
 #define XML_GET_TRANSACTION_INFO_REQUEST "GET_TRANSACTION_INFO"
 #define XML_GET_BUSTAT_REQUEST "GET_BUSTAT"
-#define XML_RESET_BUSTAT_REQUEST "GET_BUSTAT"
+#define XML_RESET_BUSTAT_REQUEST "RESET_BUSTAT"
 #define XML_GET_DBSPEC_REQUEST "GET_DBSPEC"
 #define XML_INIT_LOGS_REQUEST "INIT_LOGS"
 #define XML_PROP_TSINFO_REQUEST "PROP_TSINFO"
 #define XML_SET_TABLESETNODE_REQUEST "SET_TABLESETNODEINFO"
 #define XML_SET_LSN_REQUEST "SET_LSN"
-#define XML_SET_RUNSTATE_REQUEST "SET_RUNSTATE"
-#define XML_SET_SYNCSTATE_REQUEST "SET_SYNCSTATE"
 #define XML_START_TABLESET_REQUEST "START_TABLESET"
 #define XML_START_RECOVER_REQUEST "START_RECOVER"
 #define XML_STOP_TABLESET_REQUEST "STOP_TABLESET"
@@ -137,47 +135,13 @@
 #define XML_DISABLE_TABLECACHE_REQUEST "MED_DISABLE_TABLECACHE"
 #define XML_ENABLE_QUERYCACHE_REQUEST "MED_ENABLE_QUERYCACHE"
 #define XML_DISABLE_QUERYCACHE_REQUEST "MED_DISABLE_QUERYCACHE"
-
-// mediator requests
-#define XML_MED_NOTIFY_REQUEST "MED_NOTIFY"
-#define XML_MED_DEFINE_TABLESET_REQUEST "MED_DEFINE_TABLESET"
-#define XML_MED_REMOVE_TABLESET_REQUEST "MED_REMOVE_TABLESET"
-#define XML_MED_RESET_TABLESET_REQUEST "MED_RESET_TABLESET"
-#define XML_MED_CREATE_TABLESET_REQUEST "MED_CREATE_TABLESET"
-#define XML_MED_CORRECT_TABLESET_REQUEST "MED_CORRECT_TABLESET"
-#define XML_MED_DROP_TABLESET_REQUEST "MED_DROP_TABLESET"
-#define XML_MED_START_TABLESET_REQUEST "MED_START_TABLESET"
-#define XML_MED_STOP_TABLESET_REQUEST "MED_STOP_TABLESET"
-#define XML_MED_COPY_TABLESET_REQUEST "MED_COPY_TABLESET"
-#define XML_MED_SWITCH_TABLESET_REQUEST "MED_SWITCH_TABLESET"
-#define XML_MED_ADD_ARCHLOG_REQUEST "MED_ADD_ARCHLOG"
-#define XML_MED_REMOVE_ARCHLOG_REQUEST "MED_REMOVE_ARCHLOG"
-#define XML_MED_ADD_DATAFILE_REQUEST "MED_ADD_DATAFILE"
-#define XML_MED_GET_TABLESETLIST_REQUEST "MED_GET_TABLESETLIST"
-#define XML_MED_GET_DETAILEDTABLESETINFO_REQUEST "MED_GET_DETAILEDTABLESETINFO"
-#define XML_MED_GET_OBJECTINFO_REQUEST "MED_GET_OBJECTINFO"
-#define XML_MED_GET_ARCHLOGINFO_REQUEST "MED_GET_ARCHLOGINFO"
-#define XML_MED_GET_TRANSACTIONINFO_REQUEST "MED_GET_TRANSACTIONINFO"
-#define XML_MED_GET_BUSTAT_REQUEST "MED_GET_BUSTAT"
-#define XML_MED_RESET_BUSTAT_REQUEST "MED_RESET_BUSTAT"
-#define XML_MED_BEGIN_BACKUP_REQUEST "MED_BEGIN_BACKUP"
-#define XML_MED_EXECUTE_BACKUP_REQUEST "MED_EXECUTE_BACKUP"
-#define XML_MED_END_BACKUP_REQUEST "MED_END_BACKUP"
-#define XML_MED_LIST_BACKUP_REQUEST "MED_LIST_BACKUP"
-#define XML_MED_RESTORE_REQUEST "MED_RESTORE"
-#define XML_MED_RECOVER_REQUEST "MED_RECOVER"
-#define XML_MED_SECSWITCH_REQUEST "MED_SECSWITCH"
-#define XML_MED_SECRELOCATE_REQUEST "MED_SECRELOCATE"
-#define XML_MED_CHECK_TABLESET_REQUEST "MED_CHECK_TABLESET"
-#define XML_MED_VERIFY_TABLESET_REQUEST "MED_VERIFY_TABLESET"
-#define XML_MED_ENABLE_ARCHLOG_REQUEST "MED_ENABLE_ARCHLOG"
-#define XML_MED_DISABLE_ARCHLOG_REQUEST "MED_DISABLE_ARCHLOG"
-#define XML_MED_ENABLE_AUTOCORRECT_REQUEST "MED_ENABLE_AUTOCORRECT"
-#define XML_MED_DISABLE_AUTOCORRECT_REQUEST "MED_DISABLE_AUTOCORRECT"
-#define XML_MED_ENABLE_APPENDMODE_REQUEST "MED_ENABLE_APPENDMODE"
-#define XML_MED_DISABLE_APPENDMODE_REQUEST "MED_DISABLE_APPENDMODE"
-#define XML_SEC_MEDSWITCH_REQUEST "SEC_MEDSWITCH"
-#define XML_SEC_MEDRELOCATE_REQUEST "SEC_MEDRELOCATE"
+#define XML_VERIFY_TABLESET_REQUEST "VERIFY_TABLESET"
+#define XML_ENABLE_ARCHLOG_REQUEST "ENABLE_ARCHLOG"
+#define XML_DISABLE_ARCHLOG_REQUEST "DISABLE_ARCHLOG"
+#define XML_ENABLE_AUTOCORRECT_REQUEST "ENABLE_AUTOCORRECT"
+#define XML_DISABLE_AUTOCORRECT_REQUEST "DISABLE_AUTOCORRECT"
+#define XML_ENABLE_APPENDMODE_REQUEST "ENABLE_APPENDMODE"
+#define XML_DISABLE_APPENDMODE_REQUEST "DISABLE_APPENDMODE"
 
 // db session requests
 #define XML_ALTERTABLE_REQUEST "ALTERTABLE"
@@ -326,7 +290,6 @@
 // xml attributes
 #define XML_ACTIVEDBTHREAD_ATTR "ACTDBTHREAD"
 #define XML_ACTIVEADMTHREAD_ATTR "ACTADMTHREAD"
-#define XML_ACTIVELOGTHREAD_ATTR "ACTLOGTHREAD"
 #define XML_ADMINPORT_ATTR "ADMINPORT"
 #define XML_AFFECTED_ATTR "AFFCOUNT"
 #define XML_AGG_ATTR "AGG"
@@ -447,7 +410,6 @@
 #define XML_QUERYCACHENUMFAIL_ATTR "QUERYCACHENUMFAIL"
 #define XML_MVAL_ATTR "MVAL"
 #define XML_MAXSENDLEN_ATTR "MAXSENDLEN"
-#define XML_MEDIATOR_ATTR "MEDIATOR"
 #define XML_MODE_ATTR "MODE"
 #define XML_MSG_ATTR "MSG"
 #define XML_NAME_ATTR "NAME"
@@ -457,7 +419,6 @@
 #define XML_NUMDBTHREAD_ATTR "NUMDBTHREAD"
 #define XML_NUMADMTHREAD_ATTR "NUMADMTHREAD"
 #define XML_NUMLOCK_ATTR "NUMLOCK"
-#define XML_NUMLOGTHREAD_ATTR "NUMLOGTHREAD"
 #define XML_NUMTOTAL_ATTR "NUMTOTAL"
 #define XML_NUMUSED_ATTR "NUMUSED"
 #define XML_NUMFREE_ATTR "NUMFREE"
@@ -511,10 +472,8 @@
 #define XML_PAGEID_ATTR "PAGEID"
 #define XML_PAGEOFFSET_ATTR "PAGEOFFSET"
 #define XML_PAGESIZE_ATTR "PAGESIZE"
-#define XML_PIDFILE_ATTR "PIDFILE"
 #define XML_PIT_ATTR "PIT"
 #define XML_POS_ATTR "POS"
-#define XML_PRIMARY_ATTR "PRIMARY"
 #define XML_PRED_ATTR "PRED"
 #define XML_PROCNAME_ATTR "PROCNAME"
 #define XML_PROCTEXT_ATTR "PROCTEXT"
@@ -530,10 +489,8 @@
 #define XML_RUNSTATE_ATTR "RUNSTATE"
 #define XML_SCANDATETIMEFORMAT_ATTR "SCANDATETIMEFORMAT"
 #define XML_SEGMENT_ATTR "SEGMENT"
-#define XML_SECONDARY_ATTR "SECONDARY"
 #define XML_SELECTTIMEOUT_ATTR "SELECTTIMEOUT"
 #define XML_STATUS_ATTR "STATUS"
-#define XML_SYNCSTATE_ATTR "SYNCSTATE"
 #define XML_SYSSIZE_ATTR "SYSSIZE"
 #define XML_SYSPAGEOFFSET_ATTR "SYSPAGEOFFSET"
 #define XML_SIZE_ATTR "SIZE"
